#
# spec file for package emotion
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           emotion
Version:        1.7.4
Release:        1.1
License:        BSD-2-Clause
Summary:        Media Library for EFL
Url:            http://enlightenment.org/
Group:          Development/Libraries/C and C++
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  doxygen
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRequires:  edje-devel >= %{version}
BuildRequires:  eet-devel >= %{version}
BuildRequires:  eio-devel >= %{version}
BuildRequires:  evas-devel >= %{version}
BuildRequires:  gstreamer-devel
BuildRequires:  libtool
BuildRequires:  xine-lib-devel
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Emotion is Media Library.

%package -n libemotion1
Summary:        Emotion shared library
Group:          Development/Libraries/C and C++

%description -n libemotion1
Contains shared library of Emotion Media Library package

%package devel
Summary:        Emotion development files
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       edje-devel >= %{version}
Requires:       eet-devel >= %{version}
Requires:       eio-devel >= %{version}
Requires:       evas-devel >= %{version}
Requires:       gstreamer-devel
Requires:       xine-lib-devel

%description devel
Development files for emotion package.

%package doc-html
Summary:        HTML documentation of Emotion
Group:          Documentation/HTML

%description doc-html
Documentation of Emotion library in form of HTML pages.

%package doc-man
Summary:        Man documentation of Emotion
Group:          Documentation/Man

%description doc-man
Documentation of Emotion library in form of man pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static --disable-silent-rules
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
echo "Copying MAN pages"
/bin/cp -vr doc/man/ %{buildroot}%{_mandir}/
# fix line endings
find %{buildroot}%{_docdir} -name '*.eps' | xargs sed -i 's@\r@\n@g'
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%fdupes -s %{buildroot}%{_mandir}
%endif
cp -v ChangeLog README COPYING* %{buildroot}%{_docdir}/%{name}/
find %{buildroot}%{_libdir} -name '*.la' -exec rm -vf {} \;

%clean
%{?buildroot:rm -rf %{buildroot}}

%post -n libemotion1 -p /sbin/ldconfig

%postun -n libemotion1 -p /sbin/ldconfig

%files -n libemotion1
%defattr(-,root,root)
%{_libdir}/libemotion.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libemotion.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/*

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/html
%dir %{_libdir}/%{name}
%{_bindir}/%{name}_*
%{_libdir}/%{name}/*.so
%{_datadir}/%{name}
%{_libdir}/edje

%files doc-html
%defattr(-, root, root)
%doc %{_docdir}/%{name}/html

%files doc-man
%defattr(-, root, root)
%{_mandir}/*/*

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-1.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since Emotion 1.7.3:
  * Add XML output to doc
  * Add installation rule for doc
* Fri Dec 21 2012 sleep_walker@suse.cz
- use vicious %%doc macro again, but now it will work, I promise
* Fri Dec 21 2012 sleep_walker@suse.cz
- remove vicious %%doc macro
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Sat Nov 24 2012 sleep_walker@suse.cz
- require the same version or higher for EFL libraries
* Sat Nov 24 2012 sleep_walker@suse.cz
- require versioned devel packages
- make find less efficient
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
* Thu Nov 22 2012 sleep_walker@suse.cz
- clean up spec
- remove autoupdate entries in changelog
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Wed Jun 27 2012 sleep_walker@suse.cz
- remove ffmpeg dependency
* Thu Mar 29 2012 sleep_walker@suse.cz
- adapted for 1.0.0
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Sat Nov 19 2011 tcech@suse.com
- add autoreconf for mandrivas
* Tue Nov  1 2011 tcech@suse.com
- add group for libemotion0 package
* Fri Oct 21 2011 tcech@suse.com
- initial commit
